@@ -42,14 +42,19 @@ def wait_for_jobs(backend: ShadeLocal, jobs: List[Jobs], paths: List[Path] = Non
             if getattr(asset, job) not in ('COMPLETED', 'FAILED'):
                 print(f"Waiting for {job} on {asset.path}")
                 return False
+            elif getattr(asset, 'preview_job_state') == 'FAILED':
+                print(f"Previews failed so theres no point in waiting on {asset.path}")
+                return True
         return True
 
-    while True:
+    for i in range(60):
         assets = [backend.assets.get_asset_by_path(asset) for asset in paths]
         if not all([__asset_has_jobs(asset) for asset in assets]):
             time.sleep(1)
         else:
-            break
+            return
+
+    raise Exception("Timed out waiting for jobs to complete")
 
 
 # @pytest.mark.parametrize('asset_name', [
